@@ -83,6 +83,36 @@ class Interpolator:
 
         return self.interp_fun
 
+    def get_cycle_function(self, num_reps=1, speed_factor = 1.0, invert_direction=False, as_list=False):
+
+
+        prefix_dur = self.prefix['time'][-1]
+        suffix_dur = self.suffix['time'][-1]
+        main_dur = self.main['time'][-1]
+        total_main_dur = main_dur/speed_factor*num_reps
+
+        def cycle_fn(t):
+            if not isinstance(t, list):
+                tl=np.asarray([t])
+            else:
+                tl=np.asarray(t)
+            
+            out=[]
+            for t_curr in tl:
+                if t_curr<prefix_dur:
+                    out.append(-2)
+                elif t_curr>prefix_dur+total_main_dur:
+                    out.append(-1)
+                else:
+                    t_test = t_curr-prefix_dur
+                    out.append(np.ceil(num_reps*t_test/total_main_dur)-1)
+            
+            if len(tl)==1 :
+                out = out[0]
+            return out
+
+        return cycle_fn
+
 
     # Get the final time of the interpolation
     def get_final_time(self):
